@@ -97,7 +97,7 @@ Widget::Widget(
 	getData()->country = ComputeNewAccountCountry();
 
 	_account->mtpValue(
-	) | rpl::start_with_next([=](not_null<MTP::Instance*> instance) {
+	) | rpl::on_next([=](not_null<MTP::Instance*> instance) {
 		_api.emplace(instance);
 		crl::on_main(this, [=] { createLanguageLink(); });
 	}, lifetime());
@@ -116,6 +116,7 @@ Widget::Widget(
 	default: Unexpected("Enter point in Intro::Widget::Widget.");
 	}
 
+	setupStep();
 	fixOrder();
 
 	if (_account->mtp().isTestMode()) {
@@ -131,17 +132,17 @@ Widget::Widget(
 	}
 
 	Lang::CurrentCloudManager().firstLanguageSuggestion(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		createLanguageLink();
 	}, lifetime());
 
 	_account->mtpUpdates(
-	) | rpl::start_with_next([=](const MTPUpdates &updates) {
+	) | rpl::on_next([=](const MTPUpdates &updates) {
 		handleUpdates(updates);
 	}, lifetime());
 
 	_back->entity()->setClickedCallback([=] { backRequested(); });
-	_back->entity()->accessibilitySetName(tr::lng_go_back(tr::now));
+	_back->entity()->setAccessibleName(tr::lng_go_back(tr::now));
 	_back->hide(anim::type::instant);
 
 	if (_changeLanguage) {
@@ -149,7 +150,7 @@ Widget::Widget(
 	}
 
 	Lang::Updated(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		refreshLang();
 	}, lifetime());
 
@@ -168,7 +169,7 @@ Widget::Widget(
 			checker.isLatest(),
 			checker.failed(),
 			checker.ready()
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			checkUpdateStatus();
 		}, lifetime());
 	}
@@ -342,6 +343,32 @@ void Widget::setInnerFocus() {
 	}
 }
 
+void Widget::setupStep() {
+	getStep()->nextButtonStyle(
+	) | rpl::on_next([=](const style::RoundButton *st) {
+		const auto nextStyle = st ? st : &st::introNextButton;
+		if (_nextStyle != nextStyle) {
+			_nextStyle = nextStyle;
+			const auto wasShown = _next->toggled();
+			_next.destroy();
+			_next.create(
+				this,
+				object_ptr<Ui::RoundButton>(this, nullptr, *nextStyle));
+			showControls();
+			updateControlsGeometry();
+			_next->toggle(wasShown, anim::type::instant);
+		}
+	}, getStep()->lifetime());
+
+	getStep()->nextButtonFocusRequests() | rpl::on_next([=] {
+		if (_next && !_next->isHidden()) {
+			_next->entity()->setFocus(Qt::OtherFocusReason);
+		}
+	}, getStep()->lifetime());
+
+	getStep()->finishInit();
+}
+
 void Widget::historyMove(StackAction action, Animate animate) {
 	Expects(_stepHistory.size() > 1);
 
@@ -363,25 +390,8 @@ void Widget::historyMove(StackAction action, Animate animate) {
 	if (_terms) {
 		hideAndDestroy(std::exchange(_terms, { nullptr }));
 	}
-	{
-		getStep()->nextButtonStyle(
-		) | rpl::start_with_next([=](const style::RoundButton *st) {
-			const auto nextStyle = st ? st : &st::introNextButton;
-			if (_nextStyle != nextStyle) {
-				_nextStyle = nextStyle;
-				const auto wasShown = _next->toggled();
-				_next.destroy();
-				_next.create(
-					this,
-					object_ptr<Ui::RoundButton>(this, nullptr, *nextStyle));
-				showControls();
-				updateControlsGeometry();
-				_next->toggle(wasShown, anim::type::instant);
-			}
-		}, _next->lifetime());
-	}
+	setupStep();
 
-	getStep()->finishInit();
 	getStep()->prepareShowAnimated(wasStep);
 	if (wasStep->hasCover() != getStep()->hasCover()) {
 		_nextTopFrom = wasStep->contentTop() + st::introNextTop;
@@ -422,7 +432,7 @@ void Widget::hideAndDestroy(object_ptr<Ui::FadeWrap<Ui::RpWidget>> widget) {
 	const auto weak = base::make_weak(widget.data());
 	widget->hide(anim::type::normal);
 	widget->shownValue(
-	) | rpl::start_with_next([=](bool shown) {
+	) | rpl::on_next([=](bool shown) {
 		if (!shown && weak) {
 			weak->deleteLater();
 		}
@@ -502,8 +512,8 @@ void Widget::showTerms() {
 			this,
 			tr::lng_terms_signup(
 				lt_link,
-				tr::lng_terms_signup_link() | Ui::Text::ToLink(),
-				Ui::Text::WithEntities),
+				tr::lng_terms_signup_link(tr::link),
+				tr::marked),
 			st::introTermsLabel);
 		_terms.create(this, std::move(entity));
 		_terms->entity()->overrideLinkClickHandler([=] {
@@ -656,7 +666,7 @@ void Widget::showTerms(Fn<void()> callback) {
 	box->setCloseByOutsideClick(false);
 
 	box->agreeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (callback) {
 			callback();
 		}
@@ -666,19 +676,19 @@ void Widget::showTerms(Fn<void()> callback) {
 	}, box->lifetime());
 
 	box->cancelClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto box = Ui::show(Box<Window::TermsBox>(
 			TextWithEntities{ tr::lng_terms_signup_sorry(tr::now) },
 			tr::lng_intro_finish(),
 			tr::lng_terms_decline()));
 		box->agreeClicks(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			if (weak) {
 				showTerms(callback);
 			}
 		}, box->lifetime());
 		box->cancelClicks(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			if (box) {
 				box->closeBox();
 			}
@@ -725,7 +735,7 @@ void Widget::setupNextButton() {
 		return !text.isEmpty();
 	}) | rpl::filter([=](bool visible) {
 		return visible != _nextShown;
-	}) | rpl::start_with_next([=](bool visible) {
+	}) | rpl::on_next([=](bool visible) {
 		_next->toggle(visible, anim::type::normal);
 		_nextShown = visible;
 		if (_changeLanguage) {
