@@ -233,7 +233,7 @@ FlatLabel::FlatLabel(
 	textUpdated();
 	std::move(
 		text
-	) | rpl::start_with_next([this](const QString &value) {
+	) | rpl::on_next([this](const QString &value) {
 		setText(value);
 	}, lifetime());
 	init();
@@ -253,7 +253,7 @@ FlatLabel::FlatLabel(
 	textUpdated();
 	std::move(
 		text
-	) | rpl::start_with_next([=](const TextWithEntities &value) {
+	) | rpl::on_next([=](const TextWithEntities &value) {
 		setMarkedText(value, context);
 	}, lifetime());
 	init();
@@ -1001,9 +1001,10 @@ DividerLabel::DividerLabel(
 	QWidget *parent,
 	object_ptr<RpWidget> &&child,
 	const style::margins &padding,
+	const style::DividerBar &st,
 	RectParts parts)
 : PaddingWrap(parent, std::move(child), padding)
-, _background(this, st::boxDividerHeight, st::boxDividerBg, parts) {
+, _background(this, st::boxDividerHeight, st, parts) {
 	setNaturalWidth(-1);
 }
 
